@@ -5,7 +5,7 @@ package Alt::Data::Frame::ButMore;
 use strict;
 use warnings;
 
-our $VERSION = '0.004_005'; # TRIAL VERSION
+our $VERSION = '0.0042_01'; # TRIAL VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Alt::Data::Frame::ButMore - Alternative implementation of Data::Frame with more
 
 =head1 VERSION
 
-version 0.004_005
+version 0.0042_01
 
 =head1 STATUS
 
@@ -522,18 +522,34 @@ This feature is somewhat similar to R's tidy evaluation.
 
 See L<Data::Frame::Partial::Eval>.
 
+=head1 VARIABLES
+
+=head1 doubleformat
+
+This is used when stringifying the data frame. Default is C<'%.8g'>.
+
+=head2 TOLERANCE_REL
+
+This is the relative tolerance used when comparing numerical values of two
+data frames.
+Default is C<undef>, which means no tolerance at all. You can set it like,
+
+    $Data::Frame::TOLERANCE_REL = 1e-8;
+
 =head1 SEE ALSO
 
 =over 4
 
 =item * L<Alt>
 
+=item * L<Data::Frame::Examples>
+
+=item * L<PDL>
+
 =item * L<R manual: data.frame|https://stat.ethz.ch/R-manual/R-devel/library/base/html/data.frame.html>.
 
 =item * L<Statistics::NiceR>
 
-=item * L<PDL>
-
 =back
 
 =head1 AUTHORS
