@@ -28,8 +28,8 @@ use PDL::SV        ();
 use PDL::StringfiableExtension;
 use Ref::Util qw(is_plain_arrayref is_plain_hashref);
 use Scalar::Util qw(blessed looks_like_number);
-use Sereal::Decoder;
-use Sereal::Encoder;
+use Sereal::Decoder 4.005;
+use Sereal::Encoder 4.005;
 use Text::Table::Tiny;
 use Type::Params;
 use Types::Standard qw(Any ArrayRef CodeRef CycleTuple HashRef Maybe Str);
@@ -1006,7 +1006,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.004_005
+version 0.0042_01
 
 =head1 STATUS
 
@@ -1507,18 +1507,34 @@ This feature is somewhat similar to R's tidy evaluation.
 
 See L<Data::Frame::Partial::Eval>.
 
+=head1 VARIABLES
+
+=head1 doubleformat
+
+This is used when stringifying the data frame. Default is C<'%.8g'>.
+
+=head2 TOLERANCE_REL
+
+This is the relative tolerance used when comparing numerical values of two
+data frames.
+Default is C<undef>, which means no tolerance at all. You can set it like,
+
+    $Data::Frame::TOLERANCE_REL = 1e-8;
+
 =head1 SEE ALSO
 
 =over 4
 
 =item * L<Alt>
 
+=item * L<Data::Frame::Examples>
+
+=item * L<PDL>
+
 =item * L<R manual: data.frame|https://stat.ethz.ch/R-manual/R-devel/library/base/html/data.frame.html>.
 
 =item * L<Statistics::NiceR>
 
-=item * L<PDL>
-
 =back
 
 =head1 AUTHORS
