@@ -12,18 +12,20 @@ use Import::Into;
 
 use Carp;
 use Data::Dumper ();
-use Function::Parameters 2.0;
+use Function::Parameters 2.001003;
+use PDL::Lite ();   # PDL::Lite is the minimal to get PDL work
 use Ref::Util    ();
 use Safe::Isa 1.000009 ();
 use Syntax::Keyword::Try ();
 use boolean              ();
+use indirect             ();
 
 use Moo 2.003004 ();
 use Moo::Role ();
 
 use List::AllUtils qw(uniq);
 
-use Moose::Autobox;
+use Moose::Autobox 0.16;
 for my $type (qw(Hash Array)) {
     Moose::Autobox->mixin_additional_role(
         uc($type) => "Data::Frame::Autobox::$type" );
@@ -65,6 +67,7 @@ sub _import_tag {
         Safe::Isa->import::into($target);
         Syntax::Keyword::Try->import::into($target);
         boolean->import::into($target);
+        indirect->unimport::out_of($target);
 
         Moose::Autobox->import::into($target);
     }
@@ -103,7 +106,7 @@ Data::Frame::Setup - Import stuffs into Data::Frame classes
 
 =head1 VERSION
 
-version 0.004_005
+version 0.0042_01
 
 =head1 SYNOPSIS
 
